@@ -6,21 +6,13 @@
 
 #include <rudiments/private/mathincludes.h>
 
-#ifdef RUDIMENTS_NAMESPACE
-namespace rudiments {
-#endif
-
-class math {
+class RUDIMENTS_DLLSPEC math {
 	public:
-		static int	absoluteValue(int j);
-		static div_t	divide(int numer, int denom);
+		static int32_t	absoluteValue(int32_t j);
+		static div_t	divide(int32_t numer, int32_t denom);
 
-		static long	absoluteValue(long j);
-		static ldiv_t	divide(long numer, long denom);
-
-		static long long	absoluteValue(long long j);
-		static lldiv_t		divide(long long numer,
-						long long denom);
+		static int64_t	absoluteValue(int64_t j);
+		static lldiv_t	divide(int64_t numer, int64_t denom);
 
 		static bool	isFinite(float x);
 		static bool	isInfinite(float x);
@@ -64,7 +56,7 @@ class math {
 
 		static float	exponent(float x);
 
-		static float	normalize(float x, int *exp);
+		static float	normalize(float x, int32_t *exp);
 
 		static float	logBase10(float x);
 
@@ -79,24 +71,24 @@ class math {
 		static float	hypotenuse(float x, float y);
 
 		static float	computeExponent(float x);
-		static int	integralExponent(float x);
-		static float 	loadExponent(float x, int exp);
+		static int32_t	integralExponent(float x);
+		static float 	loadExponent(float x, int32_t exp);
 
 		static float	ceiling(float x);
 		static float	floor(float x);
 		static float	absoluteValue(float x);
 
 		static float	remainder(float x, float y);
-		static float	remainder(float x, float y, int *quo);
+		static float	remainder(float x, float y, int32_t *quo);
 
 		static float	truncate(float x);
 		static float	nearbyInteger(float x);
 		static float	round(float x);
 		static float	roundInexact(float x);
-		static long		roundToLong(float x);
-		static long long	roundToLongLong(float x);
-		static long		roundAwayFromZeroToLong(float x);
-		static long long	roundAwayFromZeroToLongLong(float x);
+		static long	roundToLong(float x);
+		static int64_t	roundToLongLong(float x);
+		static long	roundAwayFromZeroToLong(float x);
+		static int64_t	roundAwayFromZeroToLongLong(float x);
 		static float	nextAfter(float x, float y);
 		static float	nextToward(float x, float y);
 
@@ -107,7 +99,7 @@ class math {
 		static float	naturalLogGamma(float x);
 
 		static float	scaleByRadixToPower(float x, float n);
-		static float	scaleByRadixToPower(float x, int n);
+		static float	scaleByRadixToPower(float x, int32_t n);
 		static float	scaleByRadixToPower(float x, long n);
 
 		static float	larger(float x, float y);
@@ -168,7 +160,7 @@ class math {
 
 		static double	exponent(double x);
 
-		static double	normalize(double x, int *exp);
+		static double	normalize(double x, int32_t *exp);
 
 		static double	logBase10(double x);
 
@@ -183,24 +175,24 @@ class math {
 		static double	hypotenuse(double x, double y);
 
 		static double	computeExponent(double x);
-		static int	integralExponent(double x);
-		static double 	loadExponent(double x, int exp);
+		static int32_t	integralExponent(double x);
+		static double 	loadExponent(double x, int32_t exp);
 
 		static double	ceiling(double x);
 		static double	floor(double x);
 		static double	absoluteValue(double x);
 
 		static double	remainder(double x, double y);
-		static double	remainder(double x, double y, int *quo);
+		static double	remainder(double x, double y, int32_t *quo);
 
 		static double	truncate(double x);
 		static double	nearbyInteger(double x);
 		static double	round(double x);
 		static double	roundInexact(double x);
-		static long		roundToLong(double x);
-		static long long	roundToLongLong(double x);
-		static long		roundAwayFromZeroToLong(double x);
-		static long long	roundAwayFromZeroToLongLong(double x);
+		static long	roundToLong(double x);
+		static int64_t	roundToLongLong(double x);
+		static long	roundAwayFromZeroToLong(double x);
+		static int64_t	roundAwayFromZeroToLongLong(double x);
 		static double	nextAfter(double x, double y);
 		static double	nextToward(double x, double y);
 
@@ -211,7 +203,7 @@ class math {
 		static double	naturalLogGamma(double x);
 
 		static double	scaleByRadixToPower(double x, double n);
-		static double	scaleByRadixToPower(double x, int n);
+		static double	scaleByRadixToPower(double x, int32_t n);
 		static double	scaleByRadixToPower(double x, long n);
 
 		static double	larger(double x, double y);
@@ -272,7 +264,7 @@ class math {
 
 		static long double	exponent(long double x);
 
-		static long double	normalize(long double x, int *exp);
+		static long double	normalize(long double x, int32_t *exp);
 
 		static long double	logBase10(long double x);
 
@@ -288,8 +280,9 @@ class math {
 							long double y);
 
 		static long double	computeExponent(long double x);
-		static int		integralExponent(long double x);
-		static long double 	loadExponent(long double x, int exp);
+		static int32_t		integralExponent(long double x);
+		static long double 	loadExponent(long double x,
+							int32_t exp);
 
 		static long double	ceiling(long double x);
 		static long double	floor(long double x);
@@ -299,16 +292,16 @@ class math {
 							long double y);
 		static long double	remainder(long double x,
 							long double y,
-							int *quo);
+							int32_t *quo);
 
 		static long double	truncate(long double x);
 		static long double	nearbyInteger(long double x);
 		static long double	round(long double x);
 		static long double	roundInexact(long double x);
 		static long		roundToLong(long double x);
-		static long long	roundToLongLong(long double x);
+		static int64_t		roundToLongLong(long double x);
 		static long		roundAwayFromZeroToLong(long double x);
-		static long long	roundAwayFromZeroToLongLong(
+		static int64_t		roundAwayFromZeroToLongLong(
 								long double x);
 		static long double	nextAfter(long double x,
 							long double y);
@@ -326,7 +319,7 @@ class math {
 		static long double	scaleByRadixToPower(long double x,
 								long double n);
 		static long double	scaleByRadixToPower(long double x,
-								int n);
+								int32_t n);
 		static long double	scaleByRadixToPower(long double x,
 								long n);
 
@@ -355,10 +348,6 @@ class math {
 
 };
 
-#ifdef RUDIMENTS_NAMESPACE
-}
-#endif
-
 #ifdef ENABLE_RUDIMENTS_INLINES
 	#include <rudiments/private/mathinlines.h>
 #endif
