@@ -1,9 +1,12 @@
 // Copyright (c) 2003 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
 #include <rudiments/private/rudimentsinlines.h>
 
 #include <sys/types.h>
 
-#include <rudiments/private/inttypes.h>
+#ifdef RUDIMENTS_HAVE_STDARG_H
+	#include <stdarg.h>
+#endif
