@@ -4,11 +4,13 @@
 	private:
 		void	appendAbortString(const char *string);
 		void	clearAbortStrings();
-		int	send(const char *string,
+		int32_t	send(const char *string,
 				constnamevaluepairs *variables);
 		void	flush();
-		int	expect(const char *string, char **abort);
-		int	substituteVariables(const char **ch,
+		int32_t	expect(const char *string, char **abort);
+		int32_t	substituteVariables(const char **ch,
 						constnamevaluepairs *variables);
+		void	charUnescape(const char *str,
+					char **newstr, bool second);
 
 		chatprivate	*pvt;
