@@ -3,16 +3,16 @@
 
 	protected:
 		char		**_connecterror();
-		long		_timeoutsec();
-		long		_timeoutusec();
-		unsigned long	_retrywait();
-		unsigned long	_retrycount();
+		int32_t		_timeoutsec();
+		int32_t		_timeoutusec();
+		uint32_t	_retrywait();
+		uint32_t	_tries();
 
 		void	initialize(char *connecterror,
-					long timeoutsec,
-					long timeoutusec,
-					unsigned long retrywait,
-					unsigned long retrycount);
+					int32_t timeoutsec,
+					int32_t timeoutusec,
+					uint32_t retrywait,
+					uint32_t tries);
 		void	clientClone(const client &c);
 
 	private:
