@@ -3,7 +3,4 @@
 
 	protected:
 		keytype		key;
-		datatype	data;
-
-		linkedlistutil<keytype>		keyutil;
-		linkedlistutil<datatype>	datautil;
+		valuetype	value;
