@@ -1,5 +1,6 @@
 // Copyright (c) 2004 David Muse
 // See the COPYING file for more information
 
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
-#include <rudiments/mutex.h>
+#include <rudiments/threadmutex.h>
