@@ -1,14 +1,14 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
 
+#include <rudiments/security.h>
 #include <rudiments/resultcodes.h>
 
-#include <sys/types.h>
-
-#ifdef RUDIMENTS_HAS_SSL
-	#include <openssl/ssl.h>
+#ifdef RUDIMENTS_HAVE_SYS_TYPES_H
+	#include <sys/types.h>
 #endif
 
 #ifdef RUDIMENTS_HAVE_SYS_SOCKET_H
@@ -24,9 +24,6 @@
 	#endif
 #endif
 
-// so STDIN_FILENO, STDOUT_FILENO, STDERR_FILENO will be defined if they need
-// to be used by the calling program...
-#ifdef RUDIMENTS_HAVE_UNISTD_H
-	#include <unistd.h>
+#ifdef RUDIMENTS_HAVE_STDARG_H
+	#include <stdarg.h>
 #endif
-#include <stdio.h>
