@@ -1,10 +1,12 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
 
 
 #if defined(RUDIMENTS_HAVE_LINUX_STATFS) || \
+	defined(RUDIMENTS_HAVE_LINUX_LIBC4_STATFS) || \
 	defined(RUDIMENTS_HAVE_CYGWIN_STATFS)
 	#include <sys/types.h>
 	#include <sys/vfs.h>
