@@ -1,8 +1,7 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
 
-#include <netdb.h>
-
-#include <rudiments/mutex.h>
+#include <rudiments/threadmutex.h>
