@@ -1,8 +1,10 @@
 // Copyright (c) 2004 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/null.h>
+
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
 #include <rudiments/private/rudimentsinlines.h>
 
-#include <stdlib.h>
 #include <complex.h>
