@@ -4,31 +4,21 @@
 #undef floor
 #undef round
 
-#ifdef RUDIMENTS_NAMESPACE
-namespace rudiments {
-#endif
-
-RUDIMENTS_INLINE int math::absoluteValue(int j) {
-	return abs(j);
-}
-
-RUDIMENTS_INLINE div_t math::divide(int numer, int denom) {
-	return div(numer,denom);
-}
-
-RUDIMENTS_INLINE long math::absoluteValue(long j) {
+RUDIMENTS_INLINE int32_t math::absoluteValue(int32_t j) {
+	// FIXME: use abs on platforms where an int is 32 bits
 	return labs(j);
 }
 
-RUDIMENTS_INLINE ldiv_t math::divide(long numer, long denom) {
+RUDIMENTS_INLINE div_t math::divide(int32_t numer, int32_t denom) {
+	// FIXME: use div on platforms where an int is 32 bits
 	return ldiv(numer,denom);
 }
 
-RUDIMENTS_INLINE long long math::absoluteValue(long long j) {
+RUDIMENTS_INLINE int64_t math::absoluteValue(int64_t j) {
 	return llabs(j);
 }
 
-RUDIMENTS_INLINE lldiv_t math::divide(long long numer, long long denom) {
+RUDIMENTS_INLINE lldiv_t math::divide(int64_t numer, int64_t denom) {
 	return lldiv(numer,denom);
 }
 
@@ -141,7 +131,7 @@ RUDIMENTS_INLINE float math::naturalExponent(float x) {
 	return expf(x);
 }
 
-RUDIMENTS_INLINE float math::normalize(float x, int *exp) {
+RUDIMENTS_INLINE float math::normalize(float x, int32_t *exp) {
 	return frexpf(x,exp);
 }
 
@@ -217,7 +207,7 @@ RUDIMENTS_INLINE float math::truncate(float x) {
 	return truncf(x);
 }
 
-RUDIMENTS_INLINE float math::remainder(float x, float y, int *quo) {
+RUDIMENTS_INLINE float math::remainder(float x, float y, int32_t *quo) {
 	return remquof(x,y,quo);
 }
 
@@ -225,7 +215,7 @@ RUDIMENTS_INLINE long math::roundToLong(float x) {
 	return lrintf(x);
 }
 
-RUDIMENTS_INLINE long long math::roundToLongLong(float x) {
+RUDIMENTS_INLINE int64_t math::roundToLongLong(float x) {
 	return llrintf(x);
 }
 
@@ -233,7 +223,7 @@ RUDIMENTS_INLINE long math::roundAwayFromZeroToLong(float x) {
 	return lroundf(x);
 }
 
-RUDIMENTS_INLINE long long math::roundAwayFromZeroToLongLong(float x) {
+RUDIMENTS_INLINE int64_t math::roundAwayFromZeroToLongLong(float x) {
 	return llroundf(x);
 }
 
@@ -273,7 +263,7 @@ RUDIMENTS_INLINE float math::scaleByRadixToPower(float x, float n) {
 	return scalbf(x,n);
 }
 
-RUDIMENTS_INLINE float math::scaleByRadixToPower(float x, int n) {
+RUDIMENTS_INLINE float math::scaleByRadixToPower(float x, int32_t n) {
 	return scalbnf(x,n);
 }
 
@@ -281,7 +271,7 @@ RUDIMENTS_INLINE float math::scaleByRadixToPower(float x, long n) {
 	return scalblnf(x,n);
 }
 
-RUDIMENTS_INLINE int math::integralExponent(float x) {
+RUDIMENTS_INLINE int32_t math::integralExponent(float x) {
 	return ilogbf(x);
 }
 
@@ -429,7 +419,7 @@ RUDIMENTS_INLINE double math::naturalExponent(double x) {
 	return exp(x);
 }
 
-RUDIMENTS_INLINE double math::normalize(double x, int *exp) {
+RUDIMENTS_INLINE double math::normalize(double x, int32_t *exp) {
 	return frexp(x,exp);
 }
 
@@ -505,7 +495,7 @@ RUDIMENTS_INLINE double math::truncate(double x) {
 	return trunc(x);
 }
 
-RUDIMENTS_INLINE double math::remainder(double x, double y, int *quo) {
+RUDIMENTS_INLINE double math::remainder(double x, double y, int32_t *quo) {
 	return remquo(x,y,quo);
 }
 
@@ -513,7 +503,7 @@ RUDIMENTS_INLINE long math::roundToLong(double x) {
 	return lrint(x);
 }
 
-RUDIMENTS_INLINE long long math::roundToLongLong(double x) {
+RUDIMENTS_INLINE int64_t math::roundToLongLong(double x) {
 	return llrint(x);
 }
 
@@ -521,7 +511,7 @@ RUDIMENTS_INLINE long math::roundAwayFromZeroToLong(double x) {
 	return lround(x);
 }
 
-RUDIMENTS_INLINE long long math::roundAwayFromZeroToLongLong(double x) {
+RUDIMENTS_INLINE int64_t math::roundAwayFromZeroToLongLong(double x) {
 	return llround(x);
 }
 
@@ -561,7 +551,7 @@ RUDIMENTS_INLINE double math::scaleByRadixToPower(double x, double n) {
 	return scalb(x,n);
 }
 
-RUDIMENTS_INLINE double math::scaleByRadixToPower(double x, int n) {
+RUDIMENTS_INLINE double math::scaleByRadixToPower(double x, int32_t n) {
 	return scalbn(x,n);
 }
 
@@ -569,7 +559,7 @@ RUDIMENTS_INLINE double math::scaleByRadixToPower(double x, long n) {
 	return scalbln(x,n);
 }
 
-RUDIMENTS_INLINE int math::integralExponent(double x) {
+RUDIMENTS_INLINE int32_t math::integralExponent(double x) {
 	return ilogb(x);
 }
 
@@ -716,7 +706,7 @@ RUDIMENTS_INLINE long double math::naturalExponent(long double x) {
 	return expl(x);
 }
 
-RUDIMENTS_INLINE long double math::normalize(long double x, int *exp) {
+RUDIMENTS_INLINE long double math::normalize(long double x, int32_t *exp) {
 	return frexpl(x,exp);
 }
 
@@ -793,7 +783,7 @@ RUDIMENTS_INLINE long double math::truncate(long double x) {
 }
 
 RUDIMENTS_INLINE long double math::remainder(long double x,
-						long double y, int *quo) {
+						long double y, int32_t *quo) {
 	return remquol(x,y,quo);
 }
 
@@ -801,7 +791,7 @@ RUDIMENTS_INLINE long math::roundToLong(long double x) {
 	return lrintl(x);
 }
 
-RUDIMENTS_INLINE long long math::roundToLongLong(long double x) {
+RUDIMENTS_INLINE int64_t math::roundToLongLong(long double x) {
 	return llrintl(x);
 }
 
@@ -809,7 +799,7 @@ RUDIMENTS_INLINE long math::roundAwayFromZeroToLong(long double x) {
 	return lroundl(x);
 }
 
-RUDIMENTS_INLINE long long math::roundAwayFromZeroToLongLong(long double x) {
+RUDIMENTS_INLINE int64_t math::roundAwayFromZeroToLongLong(long double x) {
 	return llroundl(x);
 }
 
@@ -850,7 +840,8 @@ RUDIMENTS_INLINE long double math::scaleByRadixToPower(long double x,
 	return scalbl(x,n);
 }
 
-RUDIMENTS_INLINE long double math::scaleByRadixToPower(long double x, int n) {
+RUDIMENTS_INLINE long double math::scaleByRadixToPower(long double x,
+								int32_t n) {
 	return scalbnl(x,n);
 }
 
@@ -858,7 +849,7 @@ RUDIMENTS_INLINE long double math::scaleByRadixToPower(long double x, long n) {
 	return scalblnl(x,n);
 }
 
-RUDIMENTS_INLINE int math::integralExponent(long double x) {
+RUDIMENTS_INLINE int32_t math::integralExponent(long double x) {
 	return ilogbl(x);
 }
 
@@ -900,18 +891,14 @@ RUDIMENTS_INLINE long double math::real(long double complex z) {
 	return creall(z);
 }
 
-RUDIMENTS_INLINE float math::loadExponent(float x, int exp) {
+RUDIMENTS_INLINE float math::loadExponent(float x, int32_t exp) {
 	return ldexpf(x,exp);
 }
 
-RUDIMENTS_INLINE double math::loadExponent(double x, int exp) {
+RUDIMENTS_INLINE double math::loadExponent(double x, int32_t exp) {
 	return ldexp(x,exp);
 }
 
-RUDIMENTS_INLINE long double math::loadExponent(long double x, int exp) {
+RUDIMENTS_INLINE long double math::loadExponent(long double x, int32_t exp) {
 	return ldexpl(x,exp);
 }
-
-#ifdef RUDIMENTS_NAMESPACE
-}
-#endif
