@@ -1,4 +1,5 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/linkedlist.h>
+#include <rudiments/private/dll.h>
+#include <rudiments/singlylinkedlist.h>
