@@ -6,13 +6,9 @@
 
 #include <rudiments/listener.h>
 
-#ifdef RUDIMENTS_NAMESPACE
-namespace rudiments {
-#endif
-
 class modemutilprivate;
 
-class modemutil {
+class RUDIMENTS_DLLSPEC modemutil {
 	public:
 			modemutil();
 		virtual	~modemutil();
@@ -23,15 +19,11 @@ class modemutil {
 		const char	*_devicename();
 		const char	*_baud();
 
-		bool	configureSerialPort(int fd, const char *baud);
+		bool	configureSerialPort(int32_t fd, const char *baud);
 
 	private:
 		modemutilprivate	*pvt;
 
 };
 
-#ifdef RUDIMENTS_NAMESPACE
-}
-#endif
-
 #endif
