@@ -1,6 +1,9 @@
 // Copyright (c) 2005 David Muse
 // See the COPYING file for more information.
 
+#include <rudiments/private/dll.h>
 #include <rudiments/private/inttypes.h>
 
+#include <rudiments/signalclasses.h>
+
 #include <sys/types.h>
