@@ -2,5 +2,5 @@
 // See the COPYING file for more information.
 
 	private:
-		bool	initialize(const char *protocolname, int number);
+		bool	initialize(const char *protocolname, int32_t number);
 		protocolentryprivate	*pvt;
