@@ -6,9 +6,4 @@
 				sharedmemory(const sharedmemory &s);
 		sharedmemory	&operator=(const sharedmemory &s);
 
-
-		int	shmGet(key_t key, size_t size, int shmflag);
-		void	*shmAttach();
-		bool	shmControl(int cmd, shmid_ds *buf);
-
 		sharedmemoryprivate	*pvt;
