@@ -1,7 +1,8 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/variablebuffer.h>
+#include <rudiments/private/dll.h>
+#include <rudiments/bytebuffer.h>
 
 #include <sys/types.h>
 
