@@ -5,15 +5,19 @@
 			void	reset();
 			void	close();
 			bool	parse();
+			bool	parseLocalFile(const char *filename);
+			bool	parseRemoteFile(const char *filename);
 			void	parseFailed();
 			bool	parseTag(char current, char *next);
 			void	parseTagFailed();
-			bool	parseTagName(char current, stringbuffer *name,
+			bool	parseTagName(char current,
+						stringbuffer *ns,
+						stringbuffer *name,
 						char *next);
 			char	parseComment(char current);
 			char	parseCData(char current);
 			char	parseAttribute(char current, char standalone);
-			int	getGeneralEntity(char breakchar);
+			int32_t	getGeneralEntity(char breakchar);
 			void	parseAttributeFailed();
 			bool	parseText(char current, char *next);
 			void	parseTextFailed();
