@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+   02110-1301 USA.  */
 
 #ifndef _REGEX_H
 #define _REGEX_H 1
@@ -445,7 +445,11 @@ typedef struct
 
 #else /* not __STDC__ */
 
-# define _RE_ARGS(args) ()
+# ifdef _WIN32
+#  define _RE_ARGS(args) args
+# else /* not _WIN32 */
+#  define _RE_ARGS(args) ()
+# endif
 
 #endif /* not __STDC__ */
 
